netapp_ontap.models.software_validation API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.software_validation`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SoftwareValidationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SoftwareValidation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `action: SoftwareValidationReferenceAction GET`

    The action field of the software_validation.

  `issue: SoftwareValidationReferenceIssue GET`

    The issue field of the software_validation.

  `status: str GET`

    Status of the update check.

    Valid choices:

    - warning
    - error
  `update_check: str GET`

    Name of the update check.

    Example: nfs_mounts